Index: net/quic/quic_client_session.h |
diff --git a/net/quic/quic_client_session.h b/net/quic/quic_client_session.h |
index 7fbe3db5cd1871dbfcff24fb8076bb03e4f5090b..b46c0ab6d8185474ba98fd8d7f8a5e4c406d53e6 100644 |
--- a/net/quic/quic_client_session.h |
+++ b/net/quic/quic_client_session.h |
@@ -87,8 +87,8 @@ class NET_EXPORT_PRIVATE QuicClientSession : public QuicClientSessionBase { |
DISALLOW_COPY_AND_ASSIGN(StreamRequest); |
}; |
// Constructs a new session which will own |connection| and |helper|, but |
// not |stream_factory|, which must outlive this session. |
// TODO(rch): decouple the factory from the session via a Delegate interface. |
QuicClientSession(QuicConnection* connection, |
scoped_ptr<DatagramClientSocket> socket, |
@@ -219,6 +219,7 @@ class NET_EXPORT_PRIVATE QuicClientSession : public QuicClientSessionBase { |
void OnConnectTimeout(); |
+ const HostPortPair server_host_port_; |
bool require_confirmation_; |
scoped_ptr<QuicCryptoClientStream> crypto_stream_; |
QuicStreamFactory* stream_factory_; |
@@ -87,8 +87,8 @@ class NET_EXPORT_PRIVATE QuicClientSession : public QuicClientSessionBase { |
DISALLOW_COPY_AND_ASSIGN(StreamRequest); |
}; |
- // Constructs a new session which will own |connection| and |helper|, but |
- // not |stream_factory|, which must outlive this session. |
+ // Constructs a new session connected to |server_id| which will own |
+ // |connection|, but not |stream_factory|, which must outlive this session. |
// TODO(rch): decouple the factory from the session via a Delegate interface. |
QuicClientSession(QuicConnection* connection, |